==> nodejs_interop-0.7.0.tar.gz: test/npm/readdir_enhanced_test.dart <==
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:nodejs_interop/src/npm.dart';
import 'package:path/path.dart' as path;
import 'package:test/test.dart';

/// Tests the features of the `readdir-enhanced` package.
void main() => group('ReaddirModule', () {
  final readdir = loadLibrary<ReaddirModule>('readdir-enhanced');

  var testDirs = const ['io', 'node', 'npm'];
  var testFiles = [path.join('npm', 'os_locale_test.dart'), path.join('npm', 'readdir_enhanced_test.dart')];

  group('.readdirAsync()', () {
    test('should list the sub-directories and files as strings', () async {
      var list = await convertToFuture<List<String>>(readdir('test'));
      for (var entity in testDirs) expect(list, contains(entity), reason: entity);

      list = await convertToFuture<List<String>>(readdir('test', new ReaddirOptions(deep: true)));
      for (var entity in testFiles) expect(list, contains(entity), reason: entity);
    });
  });

  group('.readdirAsyncStat()', () {
    test('should list the sub-directories and files as `Stats`', () async {
      var list = await convertToFuture<List<Stats>>(readdir.readdirAsyncStat('test'));
      for (var stats in list) expect(stats.isDirectory() || stats.isFile(), isTrue);
    });
  });

  group('.readdirStream()', () {
    test('should stream the sub-directories and files as strings', () async {
      var list = await convertToStream<String>(readdir.stream('test')).toList();
      for (var entity in testDirs) expect(list, contains(entity), reason: entity);

      list = await convertToStream<String>(readdir.stream('test', new ReaddirOptions(deep: true))).toList();
      for (var entity in testFiles) expect(list, contains(entity), reason: entity);
    });
  });

  group('.readdirStreamStat()', () {
    test('should stream the sub-directories and files as `Stats`', () async {
      var stream = convertToStream<Stats>(readdir.readdirStreamStat('test'));
      await for (var stats in stream) expect(stats.isDirectory() || stats.isFile(), isTrue);
    });
  });

  group('.readdirSync()', () {
    test('should synchronously list the sub-directories and files as strings', () {
      var list = readdir.sync('test');
      for (var entity in testDirs) expect(list, contains(entity), reason: entity);

      list = readdir.sync('test', new ReaddirOptions(deep: true));
      for (var entity in testFiles) expect(list, contains(entity), reason: entity);
    });
  });

  group('.readdirSyncStat()', () {
    test('should synchronously list the sub-directories and files as `Stats`', () {
      var list = readdir.readdirSyncStat('test');
      for (var stats in list) expect(stats.isDirectory() || stats.isFile(), isTrue);
    });
  });
});

==> nodejs_interop-0.8.0.tar.gz: test/npm/readdir_enhanced_test.dart <==
import 'package:nodejs_interop/js.dart';
import 'package:nodejs_interop/node.dart';
import 'package:nodejs_interop/npm.dart';
import 'package:path/path.dart' as path;
import 'package:test/test.dart';

/// Tests the features of the `readdir-enhanced` package.
void main() => group('ReaddirModule', () {
  final ReaddirModule readdir = require('readdir-enhanced');

  var testDirs = const ['io', 'node', 'npm'];
  var testFiles = [path.join('npm', 'os_locale_test.dart'), path.join('npm', 'readdir_enhanced_test.dart')];

  group('.readdirAsync()', () {
    test('should list the sub-directories and files as strings', () async {
      var list = await asFuture<List<String>>(readdir('test'));
      for (var entity in testDirs) expect(list, contains(entity), reason: entity);

      list = await asFuture<List<String>>(readdir('test', new ReaddirOptions(deep: true)));
      for (var entity in testFiles) expect(list, contains(entity), reason: entity);
    });
  });

  group('.readdirAsyncStat()', () {
    test('should list the sub-directories and files as `Stats`', () async {
      var list = await asFuture<List<Stats>>(readdir.readdirAsyncStat('test'));
      for (var stats in list) expect(stats.isDirectory() || stats.isFile(), isTrue);
    });
  });

  group('.readdirStream()', () {
    test('should stream the sub-directories and files as strings', () async {
      var list = await asStream<String>(readdir.stream('test')).toList();
      for (var entity in testDirs) expect(list, contains(entity), reason: entity);

      list = await asStream<String>(readdir.stream('test', new ReaddirOptions(deep: true))).toList();
      for (var entity in testFiles) expect(list, contains(entity), reason: entity);
    });
  });

  group('.readdirStreamStat()', () {
    test('should stream the sub-directories and files as `Stats`', () async {
      var stream = asStream<Stats>(readdir.readdirStreamStat('test'));
      await for (var stats in stream) expect(stats.isDirectory() || stats.isFile(), isTrue);
    });
  });

  group('.readdirSync()', () {
    test('should synchronously list the sub-directories and files as strings', () {
      var list = readdir.sync('test');
      for (var entity in testDirs) expect(list, contains(entity), reason: entity);

      list = readdir.sync('test', new ReaddirOptions(deep: true));
      for (var entity in testFiles) expect(list, contains(entity), reason: entity);
    });
  });

  group('.readdirSyncStat()', () {
    test('should synchronously list the sub-directories and files as `Stats`', () {
      var list = readdir.readdirSyncStat('test');
      for (var stats in list) expect(stats.isDirectory() || stats.isFile(), isTrue);
    });
  });
});
